%Pstudent_plot
% Plots graphs of t-distribution probabilities i.e. P( t<= t* ) vs t*
%
% LAST UPDATED by Dr Andy French September 2017

function Pstudent_plot

%Set fontsize
fsize = 18;

%Set number of plot points
N = 1000;

%Set numbers of samples n in t-test
n = [3,5,10,30];

%Min and max t values
tmin = -3;
tmax = 3;

%

%Generate vector of t values
t = linspace(tmin,tmax,N).';

%Generate t-distribution
P = zeros(N,length(n));
for k=1:length(n)
    P(:,k) = tcdf(t,n(k)-1);
end

%Generate standard Normal distribution probability function
P(:,k+1) = 0.5 + 0.5*erf( t/sqrt(2) );

%Form legend string
lgnd_str ={};
for k=1:length(n)
    lgnd_str{k} = ['n = ',num2str(n(k))];
end
lgnd_str{k+1} = 'Normal';

%Plot distributions
figure('name','t distribution','color',[1 1 1])
plot(repmat(t,[1,length(n)+1]),P);
legend(lgnd_str,'location','NorthWest');
xlim([tmin,tmax])
title('t-distribution','fontsize',fsize);
xlabel('t','fontsize',fsize);
ylabel('P( T \leq t )','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
box on;
print(gcf,'t-distribution probabilities.png','-r300','-dpng')
close(gcf);

%End of code