%plot_tinv_vs_tpdf
% Plots the cumulative distribution function vs its inverse for Student's
% t-distribution.
%
% LAST UPDATED by Dr Andy French September 2017

function plot_tinv_vs_tpdf

%Set fontsize
fsize = 18;

%Set number of plot points
N = 1000;

%Set numbers of samples n in t-test for plot
n = [3,5,10,30];

%Define t limits
tmin = 0;
tmax = 1;

%

% CDF %

%Generate vector of t values
t = linspace(tmin,tmax,N).';

%Calculate y values
y = zeros(N,length(n));
for k=1:length(n)
    y(:,k) = tcdf( t, n(k)-1 );
end

%Find P values using Normal distribution
y(:,k+1) = 0.5 + 0.5*erf(t/sqrt(2));

%

% Inverse %

%Calculate yy values
yy = zeros(N,length(n));
for k=1:length(n)
    yy(:,k) = tinv( t, n(k)-1 );
end

%Find t values using Normal distribution
yy(:,k+1) = sqrt(2)*erfinv( 2*t-1 );

%

%Form legend string
lgnd_str ={};
for k=1:length(n)
    lgnd_str{k} = ['n = ',num2str(n(k))];
end
lgnd_str{k+1} = 'Normal';

%Plot distributions
t = repmat(t,[1,length(n)+1] );
figure('name','t distribution','color',[1 1 1])
plot(t,y,'-',t,yy,'--');
hold on;
legend(lgnd_str,'location','NorthWest');
axis equal
xlim([0,1])
ylim([0,1])
title('t-distribution CDF vs inverse CDF','fontsize',fsize);
xlabel('t','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
box on;
print(gcf,'tinv vs tcdf.png','-r300','-dpng')
close(gcf);

%End of code