%student_plot
% Plots a variety of t-distribution probability densities, vs a Normal
% distribution for zero mean and unity standard deviation.
%
% LAST UPDATED by Dr Andy French September 2017

function student_plot

%Set fontsize
fsize = 18;

%Set number of plot points
N = 1000;

%Set numbers of samples n in t-test
n = [3,5,10,30];

%Min and max t values
tmin = -3;
tmax = 3;

%

%Generate vector of t values
t = linspace(tmin,tmax,N).';

%Generate t-distribution
p = zeros(N,length(n));
for k=1:length(n)
    p(:,k) = tpdf(t,n(k)-1);
end

%Generate standard Normal distribution
p(:,k+1) = (1/sqrt(2*pi))*exp( -0.5*t.^2 );

%Form legend string
lgnd_str ={};
for k=1:length(n)
    lgnd_str{k} = ['n = ',num2str(n(k))];
end
lgnd_str{k+1} = 'Normal';

%Plot distributions
figure('name','t distribution','color',[1 1 1])
plot(repmat(t,[1,length(n)+1]),p);
legend(lgnd_str);
xlim([tmin,tmax])
title('t-distribution','fontsize',fsize);
xlabel('t','fontsize',fsize);
ylabel('p(t)','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
box on;
print(gcf,'t-distribution.png','-r300','-dpng')
close(gcf);

%End of code