%student_t_from_P_plot
% Plots t values of the t-distribution such that P( abs(t) <= tt ) = k.
% Also generates an Excel table of t values to match the one in
% https://en.wikipedia.org/wiki/Student%27s_t-distribution
%
% LAST UPDATED by Dr Andy French September 2017

function student_t_from_P_plot

%Set fontsize
fsize = 18;

%Set number of plot points
N = 1000;

%Set numbers of samples n in t-test for plot
n = [3,5,10,30];

%Set n and P values for Excel table
nex = [2:30,40,50,60,80,100,120];
Pex = [0.75,0.8,0.85,0.9,0.95,0.975,0.99,0.995,0.9975,0.999,0.9995];

%

%Generate vector of probabilities
P = linspace(0.5,0.999,N).';

%Calculate t values
t = zeros(N,length(n));
for k=1:length(n)
    t(:,k) = tinv( P, n(k)-1 );
end

%Find t values using Normal distribution
t(:,k+1) = sqrt(2)*erfinv( 2*P-1 );

%Form legend string
lgnd_str ={};
for k=1:length(n)
    lgnd_str{k} = ['n = ',num2str(n(k))];
end
lgnd_str{k+1} = 'Normal';

%Plot distributions
figure('name','t distribution','color',[1 1 1])
plot(repmat(P,[1,length(n)+1]),t);
legend(lgnd_str,'location','NorthWest');
xlim([0.5,1])
ylim([0,20])
title('t-distribution critical t values','fontsize',fsize);
ylabel('t','fontsize',fsize);
xlabel('P( T \leq t )','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
box on;
print(gcf,'t-distribution t vs P.png','-r300','-dpng')
close(gcf);

%

%Generate Excel table
t = zeros(length(nex),length(Pex));
for k=1:length(nex)
    t(k,:) = tinv( Pex,nex(k)-1 );
end
X{1,1} = 'Critical t values of Student t distribution';
X{2,1} = 'v = n-1';
for k=1:length(Pex)
    X{2,1+k} = Pex(k);
end
for k=1:length(nex)
    X{2+k,1} = nex(k) - 1;
end
for i=1:length(nex)
    for j=1:length(Pex)
        X{2+i,1+j} = t(i,j);
    end
end
xlswrite('t vs P.xls',X);

%End of code